@@ -1,5 +1,5 @@
 from rkclient.client import RKClient, PEM, add_pem_context, get_pem_from_request, Artifact
-from rkclient.serialization import ArtifactSerialization, PEMSerialization
+from rkclient.serialization import ArtifactSerialization, PEMSerialization, Info, deserialize_info
 from rkclient.admin import RKAdmin
 from rkclient.factory import RKClientFactory
 
