@@ -1,6 +1,7 @@
 import ast
 import json
 import logging
+import time
 from typing import Tuple, List, Optional, Any, Callable, Dict
 from uuid import UUID
 
@@ -27,10 +28,19 @@ class RKAdmin:
         self.receiver_client = RKClient(receiver_url, emitter_id=None, timeout_sec=timeout_sec, insecure=insecure,
                                         user_auth=user_auth, puc_auth=puc_auth)
         graph_builder_url = graph_builder_url.rstrip('/')
-        log.info(f"Connecting to graph builder: {graph_builder_url}")
+        log.info(f"Connecting to Graph Builder: {graph_builder_url}")
         self.graph_builder_client = RequestHelper(graph_builder_url, timeout_sec=timeout_sec, insecure=insecure,
                                                   user_auth=user_auth, puc_auth=puc_auth)
 
+    def check_connections(self) -> Tuple[str, bool]:
+        msg, ok = self.graph_builder_client.get("/info")
+        if not ok:
+            return f"Graph Builder connection error: {msg}", False
+        msg, ok = self.receiver_client.get_info()
+        if not ok:
+            return f"Receiver connection error: {msg}", False
+        return 'OK', True
+
     def graph_rebuild(self) -> Tuple[str, bool]:
         """
         :return: first element: error message or 'OK'
@@ -47,10 +57,12 @@ class RKAdmin:
         :return: first element: error message or 'OK'
                  second element: True for success, False for error
         """
+        start_time = time.time()
         text, ok = self.graph_builder_client.post("/flush", "{}")
+        total_flush_time = time.time() - start_time
         if not ok:
-            return f"Flushing queue failed: {text}", False
-        return 'OK', True
+            return f"flushing queue failed: {text}", False
+        return f"flushing queue finished, in {total_flush_time:.2f}s", True
 
     def clean_dbs(self) -> Tuple[str, bool]:
         """
@@ -69,6 +81,7 @@ class RKAdmin:
                  sort_order: str = '',
                  filters: Optional[Dict] = None) -> Tuple[List[PEM], str, bool]:
         """
+        Returns pems from sql db.
         :param page_index:
         :param page_size:
         :param sort_field:
@@ -160,7 +173,7 @@ class RKAdmin:
                             source: str = 'sqldb',
                             filters: Optional[Dict] = None) -> Tuple[int, str, bool]:
         """
-        :param source: from which db to return artifacts, currenntly only 'sqldb' supported
+        :param source: from which db to return artifacts, 'sqldb' or 'graphdb'.
         :param filters: contains dict of key:value pairs, which all has to be contained in artifact to be counted
         :return: first element: count of artifact objs
                  second element: optional str error message
@@ -175,8 +188,17 @@ class RKAdmin:
             objs = json.loads(text)
             return int(objs['artifacts_count']), "", True
 
+        def _get_artifacts_count_from_graph() -> Tuple[int, str, bool]:
+            text, ok = self.query_graph('MATCH (a:Artifact) RETURN count(a);', 'r')
+            if not ok:
+                return -1, text, False
+            result = ast.literal_eval(text)
+            return int(result[0][0]), "", True
+
         if source == 'sqldb':
             return _handle_request(_get_artifacts_count_from_sql, 'Getting artifacts count')
+        elif source == 'graphdb':
+            return _handle_request(_get_artifacts_count_from_graph, 'Getting artifacts count')
         else:
             return -1, f"Getting artifacts count: didn't recognize source: {source}", False
 
