@@ -26,7 +26,7 @@ class Artifact:
         self.ID = id
         self.Type = artifact_type
         self.Properties = properties
-        self.CreatedAt = None
+        self.CreatedAt: Optional[str] = None
         self.TaxonomyFiles: Optional[Dict] = None
         self.SolelyID = solely_id
 
