@@ -1,7 +1,10 @@
 import base64
 import json
+from json import JSONDecodeError
+
 from uuid import UUID
-from typing import Dict
+from typing import Dict, Optional
+from dataclasses import dataclass
 
 from rkclient.entities import Artifact, PEM
 
@@ -104,3 +107,19 @@ def _decode_from_base64(content_base64: str) -> str:
     content_bytes = base64.b64decode(content_base64_bytes)
     content = content_bytes.decode()
     return content
+
+
+@dataclass
+class Info:
+    version: str
+    pem_size_limit: int
+    auth_required: bool
+    pem_auth_required: bool
+
+
+def deserialize_info(s: str) -> Optional[Info]:
+    try:
+        json_obj = json.loads(s)
+        return Info(**json_obj)
+    except JSONDecodeError:
+        return None
